
#include "yodl.h"

void
gram_ERROR ()
{
  char
   *msg;

  msg = gram_parlist (builtin_get (idx_ERROR), 0);

  message (3, "%s %s\n", builtin_get (idx_ERROR), str_short (msg));

  flags.warn = 1;		/* make sure warnings printed */
  gram_warn ("ERROR ", "%s\n", msg);	/* output message */

  /*
    hmm, no tries at recovery?
   */
  exit (1);			/* failure */
}
